import React, { Component } from 'react';
import './set-password.scss'
import { withFormik, Form, Field } from "formik";
import PasswordInput from '../common/passwordInput'
import Button from '../common/Button'
import classnames from 'classnames'
import { compose } from 'redux'
import { HeaderBar } from "@/common";
import { http, api } from "@/utils";
import { Toast } from "antd-mobile";
import { encrypt } from "@/components/passport/encryption";
import { Link } from "react-router-dom";
import { isEmpty } from "lodash";


class SetPassword extends Component {

    render() {
        const {values, errors} = this.props
        return (
            <>
                <HeaderBar arrow={true} title={'设置密码'}/>
                <div className={'set-password'}>
                    <p className='title'>密码需要包含6-16位字母及数字</p>
                    <Form>
                        <Field
                            name='password'
                            render={({field}) => {
                                return (
                                    <PasswordInput
                                        autoComplete={'on'}
                                        placeholder={'设置密码'}
                                        onChange={this.handleChange}
                                        {...field}
                                    />
                                )
                            }}
                        />
                        <Button className={'btn-active'}
                                active={values.password && values.agreement && isEmpty(errors)}>完成</Button>
                        <label htmlFor="agreement" className='user-agreement'>
                            <Field type='checkbox'
                                   name='agreement'
                                   id='agreement'
                                   className={classnames([
                                       this.props.values.agreement ? 'iconfont iconiconfront-3' : 'disagree'
                                   ])}
                            />
                            同意<span>《七月在线用户使用协议》</span>
                        </label>
                    </Form>
                    <div className="skip">
                        <Link replace to='/passport/account-login'>跳过</Link>
                    </div>
                </div>
            </>
        );
    }
}

const formikConfig = {
    mapPropsToValues() {
        return {
            password: '',
            agreement: true
        }
    },
    handleSubmit: (values, {props}) => {

        let key = sessionStorage.getItem('r_type') === 'email' ? 'email' : 'tel'
        let encrypted = encrypt(values.password)

        http.post(`${api['passport-api']}/account/up_pass${key === 'tel' && '_by_phone' || ''}`, {
            [key]: sessionStorage.getItem(key),
            pass: encrypted,
            re_pass: encrypted
        })
            .then(res => {
                if (res.data.errno == 0) {
                    Toast.info('密码设置成功')
                    setTimeout(function () {
                        props.history.replace('/passport')
                    }, 1000)
                } else {
                    Toast.info(res.data.msg, 2, null, false)
                }
            })

    },
    validateOnChange: false,
    validate: (values) => {
        let errors = {}
        const re = /^(?![0-9]+$)(?![a-zA-Z]+$)[0-9A-Za-z]{6,16}$/;
        if (!re.test(values.password)) {
            errors.password = '密码需要包含6-16位字母及数字'
            Toast.info(errors.password, 2, null, false)
        }
        if (!values.agreement) {
            errors.agreement = '您须同意《七月在线用户使用协议》'
            Toast.info(errors.agreement, 2, null, false)
        }
        return errors
    }
}

export default compose(
    withFormik(formikConfig)
)(SetPassword);